Development
-----------

To get set up for development, activate your virtualenv and use pip to install
from ``dev-requirements.txt``:

.. code-block:: sh

    $ pip install -r dev-requirements.txt

To run the tests:

.. code-block:: sh

    $ python manage.py test --settings tests.settings

